==> gs2-java-sdk-3.1.165-sources.jar: io/gs2/stateMachine/model/Namespace.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.stateMachine.model;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.model.IModel;


@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class Namespace implements IModel, Serializable, Comparable<Namespace> {
	private String namespaceId;
	private String name;
	private String description;
	private ScriptSetting startScript;
	private ScriptSetting passScript;
	private ScriptSetting errorScript;
	private Long lowestStateMachineVersion;
	private LogSetting logSetting;
	private Long createdAt;
	private Long updatedAt;
	private Long revision;
	public String getNamespaceId() {
		return namespaceId;
	}
	public void setNamespaceId(String namespaceId) {
		this.namespaceId = namespaceId;
	}
	public Namespace withNamespaceId(String namespaceId) {
		this.namespaceId = namespaceId;
		return this;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public Namespace withName(String name) {
		this.name = name;
		return this;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Namespace withDescription(String description) {
		this.description = description;
		return this;
	}
	public ScriptSetting getStartScript() {
		return startScript;
	}
	public void setStartScript(ScriptSetting startScript) {
		this.startScript = startScript;
	}
	public Namespace withStartScript(ScriptSetting startScript) {
		this.startScript = startScript;
		return this;
	}
	public ScriptSetting getPassScript() {
		return passScript;
	}
	public void setPassScript(ScriptSetting passScript) {
		this.passScript = passScript;
	}
	public Namespace withPassScript(ScriptSetting passScript) {
		this.passScript = passScript;
		return this;
	}
	public ScriptSetting getErrorScript() {
		return errorScript;
	}
	public void setErrorScript(ScriptSetting errorScript) {
		this.errorScript = errorScript;
	}
	public Namespace withErrorScript(ScriptSetting errorScript) {
		this.errorScript = errorScript;
		return this;
	}
	public Long getLowestStateMachineVersion() {
		return lowestStateMachineVersion;
	}
	public void setLowestStateMachineVersion(Long lowestStateMachineVersion) {
		this.lowestStateMachineVersion = lowestStateMachineVersion;
	}
	public Namespace withLowestStateMachineVersion(Long lowestStateMachineVersion) {
		this.lowestStateMachineVersion = lowestStateMachineVersion;
		return this;
	}
	public LogSetting getLogSetting() {
		return logSetting;
	}
	public void setLogSetting(LogSetting logSetting) {
		this.logSetting = logSetting;
	}
	public Namespace withLogSetting(LogSetting logSetting) {
		this.logSetting = logSetting;
		return this;
	}
	public Long getCreatedAt() {
		return createdAt;
	}
	public void setCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
	}
	public Namespace withCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
		return this;
	}
	public Long getUpdatedAt() {
		return updatedAt;
	}
	public void setUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
	}
	public Namespace withUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
		return this;
	}
	public Long getRevision() {
		return revision;
	}
	public void setRevision(Long revision) {
		this.revision = revision;
	}
	public Namespace withRevision(Long revision) {
		this.revision = revision;
		return this;
	}

    public static Namespace fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new Namespace()
            .withNamespaceId(data.get("namespaceId") == null || data.get("namespaceId").isNull() ? null : data.get("namespaceId").asText())
            .withName(data.get("name") == null || data.get("name").isNull() ? null : data.get("name").asText())
            .withDescription(data.get("description") == null || data.get("description").isNull() ? null : data.get("description").asText())
            .withStartScript(data.get("startScript") == null || data.get("startScript").isNull() ? null : ScriptSetting.fromJson(data.get("startScript")))
            .withPassScript(data.get("passScript") == null || data.get("passScript").isNull() ? null : ScriptSetting.fromJson(data.get("passScript")))
            .withErrorScript(data.get("errorScript") == null || data.get("errorScript").isNull() ? null : ScriptSetting.fromJson(data.get("errorScript")))
            .withLowestStateMachineVersion(data.get("lowestStateMachineVersion") == null || data.get("lowestStateMachineVersion").isNull() ? null : data.get("lowestStateMachineVersion").longValue())
            .withLogSetting(data.get("logSetting") == null || data.get("logSetting").isNull() ? null : LogSetting.fromJson(data.get("logSetting")))
            .withCreatedAt(data.get("createdAt") == null || data.get("createdAt").isNull() ? null : data.get("createdAt").longValue())
            .withUpdatedAt(data.get("updatedAt") == null || data.get("updatedAt").isNull() ? null : data.get("updatedAt").longValue())
            .withRevision(data.get("revision") == null || data.get("revision").isNull() ? null : data.get("revision").longValue());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("namespaceId", getNamespaceId());
                put("name", getName());
                put("description", getDescription());
                put("startScript", getStartScript() != null ? getStartScript().toJson() : null);
                put("passScript", getPassScript() != null ? getPassScript().toJson() : null);
                put("errorScript", getErrorScript() != null ? getErrorScript().toJson() : null);
                put("lowestStateMachineVersion", getLowestStateMachineVersion());
                put("logSetting", getLogSetting() != null ? getLogSetting().toJson() : null);
                put("createdAt", getCreatedAt());
                put("updatedAt", getUpdatedAt());
                put("revision", getRevision());
            }}
        );
    }

	@Override
	public int compareTo(Namespace o) {
		return namespaceId.compareTo(o.namespaceId);
	}

	@Override
	public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((this.namespaceId == null) ? 0 : this.namespaceId.hashCode());
        result = prime * result + ((this.name == null) ? 0 : this.name.hashCode());
        result = prime * result + ((this.description == null) ? 0 : this.description.hashCode());
        result = prime * result + ((this.startScript == null) ? 0 : this.startScript.hashCode());
        result = prime * result + ((this.passScript == null) ? 0 : this.passScript.hashCode());
        result = prime * result + ((this.errorScript == null) ? 0 : this.errorScript.hashCode());
        result = prime * result + ((this.lowestStateMachineVersion == null) ? 0 : this.lowestStateMachineVersion.hashCode());
        result = prime * result + ((this.logSetting == null) ? 0 : this.logSetting.hashCode());
        result = prime * result + ((this.createdAt == null) ? 0 : this.createdAt.hashCode());
        result = prime * result + ((this.updatedAt == null) ? 0 : this.updatedAt.hashCode());
        result = prime * result + ((this.revision == null) ? 0 : this.revision.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o)
			return true;
		if (o == null)
			return false;
		if (getClass() != o.getClass())
			return false;
		Namespace other = (Namespace) o;
		if (namespaceId == null) {
			return other.namespaceId == null;
		} else if (!namespaceId.equals(other.namespaceId)) {
			return false;
		}
		if (name == null) {
			return other.name == null;
		} else if (!name.equals(other.name)) {
			return false;
		}
		if (description == null) {
			return other.description == null;
		} else if (!description.equals(other.description)) {
			return false;
		}
		if (startScript == null) {
			return other.startScript == null;
		} else if (!startScript.equals(other.startScript)) {
			return false;
		}
		if (passScript == null) {
			return other.passScript == null;
		} else if (!passScript.equals(other.passScript)) {
			return false;
		}
		if (errorScript == null) {
			return other.errorScript == null;
		} else if (!errorScript.equals(other.errorScript)) {
			return false;
		}
		if (lowestStateMachineVersion == null) {
			return other.lowestStateMachineVersion == null;
		} else if (!lowestStateMachineVersion.equals(other.lowestStateMachineVersion)) {
			return false;
		}
		if (logSetting == null) {
			return other.logSetting == null;
		} else if (!logSetting.equals(other.logSetting)) {
			return false;
		}
		if (createdAt == null) {
			return other.createdAt == null;
		} else if (!createdAt.equals(other.createdAt)) {
			return false;
		}
		if (updatedAt == null) {
			return other.updatedAt == null;
		} else if (!updatedAt.equals(other.updatedAt)) {
			return false;
		}
		if (revision == null) {
			return other.revision == null;
		} else if (!revision.equals(other.revision)) {
			return false;
		}
		return true;
	}
}

==> gs2-java-sdk-3.1.201-sources.jar: io/gs2/stateMachine/model/Namespace.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.stateMachine.model;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.model.IModel;


@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class Namespace implements IModel, Serializable, Comparable<Namespace> {
	private String namespaceId;
	private String name;
	private String description;
	private String supportSpeculativeExecution;
	private TransactionSetting transactionSetting;
	private ScriptSetting startScript;
	private ScriptSetting passScript;
	private ScriptSetting errorScript;
	private Long lowestStateMachineVersion;
	private LogSetting logSetting;
	private Long createdAt;
	private Long updatedAt;
	private Long revision;
	public String getNamespaceId() {
		return namespaceId;
	}
	public void setNamespaceId(String namespaceId) {
		this.namespaceId = namespaceId;
	}
	public Namespace withNamespaceId(String namespaceId) {
		this.namespaceId = namespaceId;
		return this;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public Namespace withName(String name) {
		this.name = name;
		return this;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Namespace withDescription(String description) {
		this.description = description;
		return this;
	}
	public String getSupportSpeculativeExecution() {
		return supportSpeculativeExecution;
	}
	public void setSupportSpeculativeExecution(String supportSpeculativeExecution) {
		this.supportSpeculativeExecution = supportSpeculativeExecution;
	}
	public Namespace withSupportSpeculativeExecution(String supportSpeculativeExecution) {
		this.supportSpeculativeExecution = supportSpeculativeExecution;
		return this;
	}
	public TransactionSetting getTransactionSetting() {
		return transactionSetting;
	}
	public void setTransactionSetting(TransactionSetting transactionSetting) {
		this.transactionSetting = transactionSetting;
	}
	public Namespace withTransactionSetting(TransactionSetting transactionSetting) {
		this.transactionSetting = transactionSetting;
		return this;
	}
	public ScriptSetting getStartScript() {
		return startScript;
	}
	public void setStartScript(ScriptSetting startScript) {
		this.startScript = startScript;
	}
	public Namespace withStartScript(ScriptSetting startScript) {
		this.startScript = startScript;
		return this;
	}
	public ScriptSetting getPassScript() {
		return passScript;
	}
	public void setPassScript(ScriptSetting passScript) {
		this.passScript = passScript;
	}
	public Namespace withPassScript(ScriptSetting passScript) {
		this.passScript = passScript;
		return this;
	}
	public ScriptSetting getErrorScript() {
		return errorScript;
	}
	public void setErrorScript(ScriptSetting errorScript) {
		this.errorScript = errorScript;
	}
	public Namespace withErrorScript(ScriptSetting errorScript) {
		this.errorScript = errorScript;
		return this;
	}
	public Long getLowestStateMachineVersion() {
		return lowestStateMachineVersion;
	}
	public void setLowestStateMachineVersion(Long lowestStateMachineVersion) {
		this.lowestStateMachineVersion = lowestStateMachineVersion;
	}
	public Namespace withLowestStateMachineVersion(Long lowestStateMachineVersion) {
		this.lowestStateMachineVersion = lowestStateMachineVersion;
		return this;
	}
	public LogSetting getLogSetting() {
		return logSetting;
	}
	public void setLogSetting(LogSetting logSetting) {
		this.logSetting = logSetting;
	}
	public Namespace withLogSetting(LogSetting logSetting) {
		this.logSetting = logSetting;
		return this;
	}
	public Long getCreatedAt() {
		return createdAt;
	}
	public void setCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
	}
	public Namespace withCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
		return this;
	}
	public Long getUpdatedAt() {
		return updatedAt;
	}
	public void setUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
	}
	public Namespace withUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
		return this;
	}
	public Long getRevision() {
		return revision;
	}
	public void setRevision(Long revision) {
		this.revision = revision;
	}
	public Namespace withRevision(Long revision) {
		this.revision = revision;
		return this;
	}

    public static Namespace fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new Namespace()
            .withNamespaceId(data.get("namespaceId") == null || data.get("namespaceId").isNull() ? null : data.get("namespaceId").asText())
            .withName(data.get("name") == null || data.get("name").isNull() ? null : data.get("name").asText())
            .withDescription(data.get("description") == null || data.get("description").isNull() ? null : data.get("description").asText())
            .withSupportSpeculativeExecution(data.get("supportSpeculativeExecution") == null || data.get("supportSpeculativeExecution").isNull() ? null : data.get("supportSpeculativeExecution").asText())
            .withTransactionSetting(data.get("transactionSetting") == null || data.get("transactionSetting").isNull() ? null : TransactionSetting.fromJson(data.get("transactionSetting")))
            .withStartScript(data.get("startScript") == null || data.get("startScript").isNull() ? null : ScriptSetting.fromJson(data.get("startScript")))
            .withPassScript(data.get("passScript") == null || data.get("passScript").isNull() ? null : ScriptSetting.fromJson(data.get("passScript")))
            .withErrorScript(data.get("errorScript") == null || data.get("errorScript").isNull() ? null : ScriptSetting.fromJson(data.get("errorScript")))
            .withLowestStateMachineVersion(data.get("lowestStateMachineVersion") == null || data.get("lowestStateMachineVersion").isNull() ? null : data.get("lowestStateMachineVersion").longValue())
            .withLogSetting(data.get("logSetting") == null || data.get("logSetting").isNull() ? null : LogSetting.fromJson(data.get("logSetting")))
            .withCreatedAt(data.get("createdAt") == null || data.get("createdAt").isNull() ? null : data.get("createdAt").longValue())
            .withUpdatedAt(data.get("updatedAt") == null || data.get("updatedAt").isNull() ? null : data.get("updatedAt").longValue())
            .withRevision(data.get("revision") == null || data.get("revision").isNull() ? null : data.get("revision").longValue());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("namespaceId", getNamespaceId());
                put("name", getName());
                put("description", getDescription());
                put("supportSpeculativeExecution", getSupportSpeculativeExecution());
                put("transactionSetting", getTransactionSetting() != null ? getTransactionSetting().toJson() : null);
                put("startScript", getStartScript() != null ? getStartScript().toJson() : null);
                put("passScript", getPassScript() != null ? getPassScript().toJson() : null);
                put("errorScript", getErrorScript() != null ? getErrorScript().toJson() : null);
                put("lowestStateMachineVersion", getLowestStateMachineVersion());
                put("logSetting", getLogSetting() != null ? getLogSetting().toJson() : null);
                put("createdAt", getCreatedAt());
                put("updatedAt", getUpdatedAt());
                put("revision", getRevision());
            }}
        );
    }

	@Override
	public int compareTo(Namespace o) {
		return namespaceId.compareTo(o.namespaceId);
	}

	@Override
	public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((this.namespaceId == null) ? 0 : this.namespaceId.hashCode());
        result = prime * result + ((this.name == null) ? 0 : this.name.hashCode());
        result = prime * result + ((this.description == null) ? 0 : this.description.hashCode());
        result = prime * result + ((this.supportSpeculativeExecution == null) ? 0 : this.supportSpeculativeExecution.hashCode());
        result = prime * result + ((this.transactionSetting == null) ? 0 : this.transactionSetting.hashCode());
        result = prime * result + ((this.startScript == null) ? 0 : this.startScript.hashCode());
        result = prime * result + ((this.passScript == null) ? 0 : this.passScript.hashCode());
        result = prime * result + ((this.errorScript == null) ? 0 : this.errorScript.hashCode());
        result = prime * result + ((this.lowestStateMachineVersion == null) ? 0 : this.lowestStateMachineVersion.hashCode());
        result = prime * result + ((this.logSetting == null) ? 0 : this.logSetting.hashCode());
        result = prime * result + ((this.createdAt == null) ? 0 : this.createdAt.hashCode());
        result = prime * result + ((this.updatedAt == null) ? 0 : this.updatedAt.hashCode());
        result = prime * result + ((this.revision == null) ? 0 : this.revision.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o)
			return true;
		if (o == null)
			return false;
		if (getClass() != o.getClass())
			return false;
		Namespace other = (Namespace) o;
		if (namespaceId == null) {
			return other.namespaceId == null;
		} else if (!namespaceId.equals(other.namespaceId)) {
			return false;
		}
		if (name == null) {
			return other.name == null;
		} else if (!name.equals(other.name)) {
			return false;
		}
		if (description == null) {
			return other.description == null;
		} else if (!description.equals(other.description)) {
			return false;
		}
		if (supportSpeculativeExecution == null) {
			return other.supportSpeculativeExecution == null;
		} else if (!supportSpeculativeExecution.equals(other.supportSpeculativeExecution)) {
			return false;
		}
		if (transactionSetting == null) {
			return other.transactionSetting == null;
		} else if (!transactionSetting.equals(other.transactionSetting)) {
			return false;
		}
		if (startScript == null) {
			return other.startScript == null;
		} else if (!startScript.equals(other.startScript)) {
			return false;
		}
		if (passScript == null) {
			return other.passScript == null;
		} else if (!passScript.equals(other.passScript)) {
			return false;
		}
		if (errorScript == null) {
			return other.errorScript == null;
		} else if (!errorScript.equals(other.errorScript)) {
			return false;
		}
		if (lowestStateMachineVersion == null) {
			return other.lowestStateMachineVersion == null;
		} else if (!lowestStateMachineVersion.equals(other.lowestStateMachineVersion)) {
			return false;
		}
		if (logSetting == null) {
			return other.logSetting == null;
		} else if (!logSetting.equals(other.logSetting)) {
			return false;
		}
		if (createdAt == null) {
			return other.createdAt == null;
		} else if (!createdAt.equals(other.createdAt)) {
			return false;
		}
		if (updatedAt == null) {
			return other.updatedAt == null;
		} else if (!updatedAt.equals(other.updatedAt)) {
			return false;
		}
		if (revision == null) {
			return other.revision == null;
		} else if (!revision.equals(other.revision)) {
			return false;
		}
		return true;
	}
}
